#
# spec file for package python-pynetbox
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-pynetbox
Version:        4.3.0
Release:        bp155.2.11
Summary:        NetBox API client library
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/digitalocean/pynetbox
Source:         https://files.pythonhosted.org/packages/source/p/pynetbox/pynetbox-%{version}.tar.gz
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module netaddr}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-netaddr
Requires:       python-requests >= 2.20.0
BuildArch:      noarch
%python_subpackages

%description
Python API client library for NetBox.

%prep
%setup -q -n pynetbox-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
# remove testsuite from sitelib
%python_expand rm -rf %{buildroot}%{$python_sitelib}/tests

%check
%pytest

%files %{python_files}
%doc README.md CHANGELOG.md
%license LICENSE
%{python_sitelib}/*

%changelog
* Mon Mar 23 2020 pgajdos@suse.com
- version update to 4.3.0
  * Adds the ability to thread calls to NetBox from .filter() and .all() methods. (PR #216)
* Tue Feb 11 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 4.2.5
  * save() is not idempotent when dealing with choice objects
    from NetBox 2.7
* Sun Jan 12 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 4.2.4
  * Fixes Nested Record Write methods
* Tue Dec 10 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 4.2.2
  * Fixes issues with hashing Record objects by adding name
    attribute to Endpoint and __eq__ method to Record objects to
    facilitate comparison.
* Wed Nov 27 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 4.2.1
  * Fixes infinite loop when filtering with paginated results.
* Wed Nov 20 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 4.2.0
  * Fix discrepancy in DetailEndpoint.create() and the docs where
    calling w/o arguments resulted in an exception.
  * Add method to return custom choices.
* Tue Nov 19 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 4.1.2
  * Fixes URL in get_session_key
* Mon Nov 18 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 4.1.1
  * Fix Endpoint.choices() by assigning http_session.
* Sat Nov 16 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 4.1.0
  * Makes use of session in requests
  * Adds Api.version property to query the NetBox version
  * Adds .choices() method to endpoint objects that utilizes DRF's
    OPTIONS method for discovering available choices for fields
    that use it. This method will eventually replace App.choices()
    when NetBox retires the /_choices endpoint.
  * Adds count() method to Endpoint object.
  * Use requests params to form URL parameters.
  * Creates a custom model for ChangeObjects and sets its __str__
    to request_id.
  * Implements __hash__ method on Record.
  * Implements JsonField object.
  * Adds local_context_data field to device model as dict.
* Fri Sep 27 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 4.0.8
  * Returns ContentError when 2XX response but not JSON.
* Mon Sep 16 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 4.0.7
  * Returns AllocationError when NetBox responds with a 204 to
    Allocation requests
  * Makes App object pickleable
- Update to version 4.0.6
  * Fixes behavior where appending an existing VLAN object id to
    tagged_vlans would cause .save() to still trigger a PATCH
    operation.
- Run testsuite
* Sat Dec 15 2018 mardnh@gmx.de
- Update to version 4.0.5
  * Fixes list comparison issue in Record._diff.
  * Returns None from Endpoint.get() when no items are found instead
    of empty list from .filter().
- Update to version 4.0.4
  * Fixes IndexError introduced by fix for #127 when field is empty
    list.
- Update to version 4.0.3
  * Fixes __iter__ method on Record object so that it properly returns
    lists of record objects. Like tagged_vlans on for Interfaces.
* Fri Dec  7 2018 mardnh@gmx.de
- Update to version 4.0.2
  * Fixes TypeError when calling save on interfaces Record with
    tagged_vlans.
* Thu Dec  6 2018 mardnh@gmx.de
- Update to version 4.0.1
  * Adds missing authentication credentials for .choices().
* Wed Dec  5 2018 mardnh@gmx.de
- Update to version 4.0.0
  Enhancements
  * Added cable endpoint support coming in NetBox 2.5.
  * Added some detail to the ValueError raised when .get() returns
    more than one object.
  * Added reserved kwargs to .get() and .filter() ("id", "pk",
    "limit", "offset").
  * Made RequestError more verbose when the NetBox API returns a
    json response. Also added more details when a 404 is returned
    (e.g. misspelled endpoints).
  API Changes
  * Switch to using PATCH instead of PUTs for updates. Also added
    an .update() method to Response objects that takes a dictionary
    to update multiple values on the object.
  * Add basic support for the _choices endpoint on each app by adding
    a choices() method to the App object.
  * - Return Record objects from .create().
  Bug Fixes
  * Raise an exception now if .filter() is passed no kwargs.
  * Fixes some miscellaneous issues related to converting certain
    Record object's fields into netaddr.IPNetwork objects. That feature
    has been removed and it simply return strings now.
* Sat Dec  1 2018 mardnh@gmx.de
- Update to versino 3.4.11
  * Bugfix release
* Thu Nov 29 2018 mardnh@gmx.de
- Update to version 3.4.10
  * Should actually fix idempotent tags (#94) now.
* Tue Nov 27 2018 mardnh@gmx.de
- Update to version 3.4.9
  * Fixes #94 where users were unable to use .append() to add a tag.
    This converts tag lists to a set and back to a list when
    serialize() is called so we don't send an update when we append
    a tag that's already there.
* Tue Nov 27 2018 mardnh@gmx.de
- Update to version 3.4.8
  * Fixes #106 by adding a units DetailEndpoint onto the Racks object
    that lets users get the devices in a rack.
    Calling netbox.dcim.racks.get(x).units.list() will return a list
    of RU objects that have a device attribute populated with a Record
    object of the device in that RU.
  * Fixes #110 in serializer that failed to handle tagged_vlans field
    correctly. This also added the ability for objects stored in lists
    to be turned into Record objects requested in #92
* Wed Oct 10 2018 mardnh@gmx.de
- Update to version 3.4.7
  * Fixes memory leak in endpoints.filter() by getting rid of
    unused CACHE variable.
- Update to version 3.4.6
  * Fixes issue with the values of data and config_context being
    turned into Record objects instead of
- Update to version 3.4.5
  * Fixes issue with IPRecord object throwing a ValueError when
    trying to turn a string containing slashes in it into an IPNetwork
    object.
  * Adds custom IPRecord object for Circuit Terminations with a string
    representation of the underlying circuit ID.
* Fri Jul 27 2018 mardnh@gmx.de
- Update to version 3.4.4
  * Fixes issue with prefix and aggregate records not being
    idempotent.
  * Adds str and repr methods for Circuit Records so that .cid is
    displayed by default.
- Update to version 3.4.3
  * Fixes issue with how non-ascii characters are handled in
    NetBox return.
- Update to version 3.4.2
  * Fixes serialization issue with selection type custom fields
  * Remove unused dependency.
- Update to version 3.4.1
  * Should fix issue introduced by switching to setuptools_scm
    for versioning.
- Update to version 3.4.0
  * Adds the ability to toggle SSL verification.
  * Sanitizes URL by removing a trailing front slash if it's present
    in the url passed at instantiation.
  * Moves to setuptools_scm for versioning.
* Thu Apr 26 2018 mardnh@gmx.de
- Update to version 3.3.1
  * Fixes issue with special characters while building the URL.
* Fri Mar 30 2018 mardnh@gmx.de
- Update to version 3.3.0
  * Adds support for napalm detail endpoint
* Fri Mar  9 2018 mardnh@gmx.de
- Update to version 3.2.0
  * Adds VirtualMachines object that properly handles
    primary_(ip|ip4|ip6) attributes.
* Wed Feb 28 2018 mardnh@gmx.de
- Update to version 3.1.0
  * Adds proper support for virtual-chassis endpoint.
  * Fixes issue with calling attributes with None value on Record
    objects after .full_details() has run. (Issue #36)
  * Adds example in docs for RequestError exceptions (Issue #28)
* Wed Feb  7 2018 mardnh@gmx.de
- Update to version 3.0.2
  * fixed docstrings with old api style
  * full_details doesn't add token
* Sun Nov 19 2017 mardnh@gmx.de
- Update to version 3.0.1
  * Added python3 support
  * Virtualization support was added
  * Added available-ips as a property of Prefix objects
  * available-prefixes was also added to Prefix objects,
    and behaves similarly to available-ips
* Tue Oct 10 2017 mardnh@gmx.de
- Initial package, version 2.1.0
